﻿/*----------------------------------------------------------------
//  <copyright file="DemoController.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.AspNetCore;
using EaCloud.AspNetCore.Mvc.Filters;
using EaCloud.AspNetCore.UI;
using EaCloud.Authorization.Functions;
using EaCloud.Authorization.Modules;
using EaCloud.Data;
using EaCloud.Filter;
using EaCloud.Mapping;
using EaCloud.Template.Pack.Demo.Core;
using EaCloud.Template.Pack.Demo.Core.Dtos;
using Microsoft.AspNetCore.Mvc;
using Microsoft.Extensions.DependencyInjection;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq.Expressions;
using System.Threading.Tasks;
using DemoEntity = EaCloud.Template.Pack.Demo.Core.Entities.Demo;

namespace EaCloud.Template.Api.Demo.Areas.Admin.Controllers.Demo
{
    #region "管理-Demo信息"
    /// <summary>
    /// 管理-Demo信息
    /// </summary>
    [Description("管理-Demo信息")]
    [ApiExplorerSettings(GroupName = "buss")]
    [ModuleInfo(Code = "Demo", Name = "Demo信息", Order = 99, Position = "Demo", PositionName = "Demo模块")]
    public class DemoController : AdminControllerBase
    {
        #region "属性"
        #region "获取 Demo服务"
        /// <summary>
        /// 获取 Demo服务
        /// </summary>
        protected IDemoService DemoService => ServiceProvider.GetService<IDemoService>();
        #endregion

        #endregion

        #region "Action方法"
        #region "读取Demo"
        /// <summary>
        /// 读取Demo
        /// </summary>
        /// <param name="request">分布查询请求</param>
        /// <returns>Demo页列表</returns>
        [HttpPost]
        [ModuleInfo]
        [Description("读取")]
        public PageData<DemoOutputDto> Read(PageRequest request)
        {
            Check.NotNull(request, nameof(request));
            IFunction function = this.GetExecuteFunction();

            Expression<Func<DemoEntity, bool>> predicate = FilterService.GetExpression<DemoEntity>(request.FilterGroup);
            var page = CacheService.ToPageCache<DemoEntity, DemoOutputDto>(DemoService.Demos, predicate, request.PageCondition, function);

            return page.ToPageData();
        }
        #endregion

        #region "新增Demo"
        /// <summary>
        /// 新增Demo
        /// </summary>
        /// <param name="dtos">新增Demo信息</param>
        /// <returns>JSON操作结果</returns>
        [HttpPost]
        [ModuleInfo]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("新增")]
        public async Task<AjaxResult> Create(DemoInputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<DemoOutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                //DemoEntity demoEntity = dto.MapTo<DemoEntity>();
                var result = await DemoService.Create(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<DemoOutputDto>());
            }
            return new AjaxResult($"Demo“{ids.ExpandAndToString()}”创建成功", outputDtos);
        }
        #endregion
        #region "更新Demo"
        /// <summary>
        /// 更新Demo
        /// </summary>
        /// <param name="dtos">Demo信息</param>
        /// <returns>JSON操作结果</returns>
        [HttpPost]
        [ModuleInfo]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("更新")]
        public async Task<AjaxResult> Update(DemoInputDto[] dtos)
        {
            Check.NotNull(dtos, nameof(dtos));
            List<string> ids = new();
            List<DemoOutputDto> outputDtos = new();
            foreach (var dto in dtos)
            {
                //DemoEntity demoEntity = dto.MapTo<DemoEntity>();
                var result = await DemoService.Update(dto);
                if (!result.Succeeded)
                {
                    return result.ToAjaxResult();
                }
                ids.Add(dto.Id.ToString());
                outputDtos.Add(dto.MapTo<DemoOutputDto>());
            }
            return new AjaxResult($"Demo“{ids.ExpandAndToString()}”更新成功", outputDtos);
        }
        #endregion
        #region "删除Demo"
        /// <summary>
        /// 删除Demo
        /// </summary>
        /// <param name="ids">要删除的编号</param>
        /// <returns>JSON操作结果</returns>
        [HttpPost]
        [ModuleInfo]
        [DependOnFunction(nameof(Read))]
        [UnitOfWork]
        [Description("删除")]
        public async Task<AjaxResult> Delete(long[] ids)
        {
            Check.NotNull(ids, nameof(ids));
            var result = await DemoService.Delete(ids);
            if (!result.Succeeded)
            {
                return result.ToAjaxResult();
            }
            return new AjaxResult($"Demo“{ids.ExpandAndToString()}”删除成功");
        }
        #endregion

        #endregion

    }
    #endregion

}
