﻿/*----------------------------------------------------------------
//  <copyright file="DemoPack.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.AspNetCore;
using EaCloud.Core.Packs;
using EaCloud.Entity;
using EaCloud.Pack.Identity.Core;
using EaCloud.Template.Pack.Demo.Core.Events;
using Microsoft.Extensions.DependencyInjection;
using System.ComponentModel;

namespace EaCloud.Template.Pack.Demo.Core
{
    #region "Demo模块"
    /// <summary>
    /// Demo模块
    /// </summary>
    [Description("Demo模块")]
    [DependsOnPacks(typeof(IdentityPack))]
    public class DemoPack : AspPackBase
    {
        #region "属性"
        #region "获取 模块级别"
        /// <summary>
        /// 获取 模块级别，级别越小越先启动
        /// </summary>
        public override PackLevel Level => PackLevel.Business;
        #endregion
        #region "获取 模块启动顺序"
        /// <summary>
        /// 获取 模块启动顺序，模块启动的顺序先按级别启动，级别内部再按此顺序启动，
        /// 级别默认为0，表示无依赖，需要在同级别有依赖顺序的时候，再重写为>0的顺序值
        /// </summary>
        public override int Order => 0;
        #endregion

        #endregion

        #region "方法"
        #region "将模块服务添加到依赖注入服务容器中"
        /// <summary>
        /// 将模块服务添加到依赖注入服务容器中
        /// </summary>
        /// <param name="services">依赖注入服务容器</param>
        /// <returns></returns>
        public override IServiceCollection AddServices(IServiceCollection services)
        {
            //瞬时模式：每次请求,都获取一个新的实例，一般使用AddScoped处理
            //services.AddTransient<IDemoStore, DemoStore>();
            //周期模式：每次请求，都获取一个新的实例。同一个请求获取多次会得到相同的实例
            services.AddScoped<IDemoStore, DemoStore>();
            //单例模式：每次都获取同一个实例
            services.AddSingleton<IDemoService, DemoService>();

            //注册种子数据
            services.AddSingleton<ISeedDataInitializer, DemoSeedDataInitializer>();
            services.AddSingleton<ISeedDataInitializer, UserSeedDataInitializer>();

            //注册事件委托
            services.AddEventHandler<DemoEventHandler>();

            return services;
        }
        #endregion

        #endregion

    }
    #endregion

}
