﻿/*----------------------------------------------------------------
//  <copyright file="DemoService.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using Microsoft.Extensions.Logging;
using System;
using System.Linq;
using System.Threading.Tasks;
using DemoEntity = EaCloud.Template.Pack.Demo.Core.Entities.Demo;
using Microsoft.Extensions.DependencyInjection;
using EaCloud;
using EaCloud.Data;
using EaCloud.Template.Pack.Demo.Core.Dtos;
using EaCloud.Mapping;

namespace EaCloud.Template.Pack.Demo.Core
{
    #region "业务实现：Demo服务"
    /// <summary>
    /// 业务实现：Demo服务
    /// </summary>
    public class DemoService : IDemoService
    {
        #region "属性"
        #region "获取 服务提供者对象"
        /// <summary>
        /// 获取 服务提供者对象
        /// </summary>
        protected IServiceProvider ServiceProvider { get; }
        #endregion
        #region "获取 日志对象"
        /// <summary>
        /// 获取 日志对象
        /// </summary>
        protected ILogger Logger => ServiceProvider.GetLogger(GetType());
        #endregion

        #region "获取 Demo存储功能"
        /// <summary>
        /// 获取 Demo存储功能
        /// </summary>
        protected IDemoStore DemoStore => ServiceProvider.GetService<IDemoStore>();
        #endregion

        #region "获取 Demo实体查询数据集"
        /// <summary>
        /// 获取 Demo实体查询数据集
        /// </summary>
        public IQueryable<DemoEntity> Demos => DemoStore.Demos;
        #endregion

        #endregion

        #region "构造函数"
        #region "初始化一个业务实现：Demo服务的新实例"
        /// <summary>
        /// 初始化一个业务实现：Demo服务（<see cref="DemoService"/>）的新实例
        /// </summary>
        /// <param name="provider">服务提供者</param>
        public DemoService(IServiceProvider provider)
        {
            ServiceProvider = provider;
        }
        #endregion

        #endregion

        #region "方法"
        #region "新增"
        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public virtual async Task<OperationResult> Create(params DemoInputDto[] dtos)
        {
            return await DemoStore.InsertByDtoAsync(dtos);
        }
        #endregion
        #region "更新"
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        public virtual async Task<OperationResult> Update(params DemoInputDto[] dtos)
        {
            return await DemoStore.UpdateByDtoAsync(dtos);
        }
        #endregion
        #region "删除"
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="demoIds">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public virtual async Task<OperationResult> Delete(params long[] demoIds)
        {
            return await DemoStore.DeleteAsync(demoIds);
        }
        #endregion

        #region "根据编号查找"
        /// <summary>
        /// 根据编号查找
        /// </summary>
        /// <param name="demoId">数据实体编号</param>
        /// <returns>业务操作结果</returns>
        public virtual async Task<OperationResult<DemoOutputDto>> FindById(long demoId)
        {
            Check.GreaterThan(demoId, nameof(demoId), 0);

            var demoOutputDto = Demos.Where(o => o.Id.Equals(demoId)).ToOutput<DemoEntity, DemoOutputDto>().FirstOrDefault();
            if (demoOutputDto != null)
            {
                return await Task.FromResult(new OperationResult<DemoOutputDto>(OperationResultType.Success, "OK", demoOutputDto));
            }

            return await Task.FromResult(new OperationResult<DemoOutputDto>(OperationResultType.QueryNull, "Not Find", demoOutputDto));
        }
        #endregion

        #endregion

    }
    #endregion

}
