﻿/*----------------------------------------------------------------
//  <copyright file="Demo.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-09-10 16:43</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Audits;
using EaCloud.Entity;
using System;
using System.ComponentModel;
using System.ComponentModel.DataAnnotations;
using System.ComponentModel.DataAnnotations.Schema;

namespace EaCloud.Template.Pack.Demo.Core.Entities
{
    #region "实体类：Demo"
    /// <summary>
    /// 实体类：Demo
    /// </summary>
    [TableNamePrefix("DMO")]
    [Table("Demo")]
    [Description("实体样例")]
    [ValueGenerate(ValueGenerateRule.Never, ValueGenerateMode.Snowflake)]
    public class Demo : EntityBase<long>, ICreatedTime, ICreationAudited<long>, IUpdateAudited<long>, IOrganizationAudited<long>, IDepartmentAudited<long>, IDataVersion, ISoftDeletable
    {
        #region "属性"
        #region "获取或设置 String"
        private string _String = "";
        /// <summary>
        /// 获取或设置 String
        /// </summary>
        [Column("String")]
        [Required]
        [DefaultValue("")]
        [StringLength(150, ErrorMessage = "{0}长度不能超过{1}")]
        [DisplayName("String")]
        public string String { get { return _String; } set { _String = value.ReplaceNull(); } }
        #endregion
        #region "获取或设置 StringCanNull"
        /// <summary>
        /// 获取或设置 StringCanNull
        /// </summary>
        [Column("StringCanNull")]
        [DisplayName("StringCanNull")]
        public string StringCanNull { get; set; }
        #endregion
        #region "获取或设置 String150，例如MSSQL：nvarchar(150)"
        /// <summary>
        /// 获取或设置 String150，例如MSSQL：nvarchar(150)
        /// </summary>
        [Column("String150")]
        [StringLength(150, ErrorMessage = "{0}长度不能超过{1}")]
        [DisplayName("String150")]
        public string String150 { get; set; }
        #endregion
        #region "获取或设置 StringMax，例如MSSQL：nvarchar(max)"
        /// <summary>
        /// 获取或设置 StringMax，例如MSSQL：nvarchar(max)
        /// </summary>
        [Column("StringMax")]
        [StringMaxLength]
        [DisplayName("StringMax")]
        public string StringMax { get; set; }
        #endregion
        #region "获取或设置 StringText，例如MSSQL：ntext"
        /// <summary>
        /// 获取或设置 StringText，例如MSSQL：ntext
        /// </summary>
        [Column("StringText")]
        [StringText]
        [DisplayName("StringText")]
        public string StringText { get; set; }
        #endregion
        #region "获取或设置 Decimal"
        /// <summary>
        /// 获取或设置 Decimal
        /// </summary>
        [Column("Decimal")]
        [DisplayName("Decimal")]
        public decimal Decimal { get; set; }
        #endregion
        #region "获取或设置 DecimalCanNull"
        /// <summary>
        /// 获取或设置 DecimalCanNull
        /// </summary>
        [Column("DecimalCanNull")]
        [DisplayName("DecimalCanNull")]
        public decimal? DecimalCanNull { get; set; }
        #endregion
        #region "获取或设置 Bool"
        /// <summary>
        /// 获取或设置 Bool
        /// </summary>
        [Column("Bool")]
        [DisplayName("Bool")]
        public bool Bool { get; set; }
        #endregion
        #region "获取或设置 Guid"
        /// <summary>
        /// 获取或设置 Guid
        /// </summary>
        [Column("Guid")]
        [DisplayName("Guid")]
        [ValueGenerate(ValueGenerateRule.Never)]
        public Guid Guid { get; set; }
        #endregion
        #region "获取或设置 Bytes"
        /// <summary>
        /// 获取或设置 Bytes
        /// </summary>
        [Column("Bytes")]
        [DisplayName("Bytes")]
        public byte[] Bytes { get; set; }
        #endregion

        #region "获取或设置 组织机构编号 IOrganizationAudited，IDepartmentAudited 可装载接口，在数据创建可自动设置当前用户登录的组织机构值"
        /// <summary>
        /// 获取或设置 组织机构编号
        /// </summary>
        [Column("OrganizationId")]
        [OrganizationFlag]
        [DisplayName("组织机构编号")]
        public long? OrganizationId { get; set; }
        #endregion
        #region "获取或设置 部门编号 IDepartmentAudited 可装载接口，在数据创建可自动设置当前用户登录的部门机构值"
        /// <summary>
        /// 获取或设置 部门编号
        /// </summary>
        [Column("DepartmentId")]
        [DepartmentFlag]
        [DisplayName("部门编号")]
        public long? DepartmentId { get; set; }
        #endregion
        #region "获取或设置 数据版本 IDataVersion 可装载接口，用于乐观锁并发处理"
        /// <summary>
        /// 获取或设置 数据版本
        /// 在实体提交验证后（增加、修改）会自动设置一个时间戳值持久化至数据库
        /// 修改、移除时取实体数据库值与提交值比对，如不一致则拒绝提交
        /// </summary>
        [Column("DataVersion")]
        [AuditIgnore]
        [DisplayName("数据版本")]
        public long DataVersion { get; set; }
        #endregion
        #region "获取或设置 创建者编号 ICreationAudited 可装载接口，在数据创建时可自动设置当前用户值"
        /// <summary>
        /// 获取或设置 创建者编号
        /// </summary>
        [Column("CreatorId")]
        [UserFlag]
        [DisplayName("创建者编号")]
        public long? CreatorId { get; set; }
        #endregion
        #region "获取或设置 创建时间 ICreatedTime，ICreationAudited  可装载接口，在数据创建时可自动设置当前时间"
        /// <summary>
        /// 获取或设置 创建时间
        /// </summary>
        [Column("CreatedTime")]
        [DisplayName("创建时间")]
        public DateTime CreatedTime { get; set; }
        #endregion
        #region "获取或设置 更新者编号 IUpdateAudited 可装载接口，在数据更新时可自动设置当前用户值"
        /// <summary>
        /// 获取或设置 更新者编号
        /// </summary>
        [DisplayName("更新者编号")]
        public long? LastUpdaterId { get; set; }
        #endregion
        #region "获取或设置 最后更新时间 IUpdateAudited 可装载接口，在数据更新时可自动设置当前时间"
        /// <summary>
        /// 获取或设置 最后更新时间
        /// </summary>
        [DisplayName("最后更新时间")]
        public DateTime? LastUpdatedTime { get; set; }
        #endregion
        #region "获取或设置 数据逻辑删除时间 ISoftDeletable 可装载接口，用于数据逻辑删除功能。注：Configuration文件中注意配置索引并且在最后增加 .IsUnique().HasFilter(null);"
        /// <summary>
        /// 获取或设置 数据逻辑删除时间
        /// ，为null表示正常数据，有值表示已逻辑删除，同时删除时间每次不同也能保证索引唯一性
        /// </summary>
        [Column("DeletedTime")]
        [DisplayName("删除时间")]
        public DateTime? DeletedTime { get; set; }
        #endregion

        #endregion

    }
    #endregion

}
