﻿/*----------------------------------------------------------------
//  <copyright file="DemoEventHandler.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.EventBuses;
using Microsoft.Extensions.Logging;
using System;
using System.Collections.Generic;
using System.Linq;

namespace EaCloud.Template.Pack.Demo.Core.Events
{
    #region "Demo事件处理器"
    /// <summary>
    /// Demo事件处理器
    /// </summary>
    public class DemoEventHandler : EventHandlerBase<DemoEventData>
    {
        //字段
        private readonly IServiceProvider _provider;

        #region "属性"
        #region "获取 日志对象"
        /// <summary>
        /// 获取 日志对象
        /// </summary>
        protected ILogger Logger => _provider.GetLogger(GetType());
        #endregion

        #endregion


        #region "构造函数"
        #region "初始化一个Demo事件处理器的新实例"
        /// <summary>
        /// 初始化一个Demo事件处理器（<see cref="DemoEventHandler"/>）的新实例
        /// </summary>
        /// <param name="provider">服务提供者</param>
        public DemoEventHandler(IServiceProvider provider)
        {
            _provider = provider;
        }
        #endregion

        #endregion

        #region "方法"
        #region "事件处理"
        /// <summary>
        /// 事件处理
        /// </summary>
        /// <param name="eventData">事件源数据</param>
        public override void Handle(DemoEventData eventData)
        {
            switch (eventData.OperateType)
            {
                case OperateType.Insert:
                    Logger.LogInformation($"创建了编号为：{eventData.Demos.Select(ul => ul.Id.ToString().ExpandAndToString())} 的 {nameof(Entities.Demo)} 数据");
                    break;
                case OperateType.Update:
                    Logger.LogInformation($"更新了编号为：{eventData.Demos.Select(ul => ul.Id.ToString().ExpandAndToString())} 的 {nameof(Entities.Demo)} 数据");
                    break;
                case OperateType.Delete:
                    Logger.LogInformation($"删除了编号为：{eventData.Demos.Select(ul => ul.Id.ToString().ExpandAndToString())} 的 {nameof(Entities.Demo)} 数据");
                    break;
            }
        }
        #endregion

        #endregion

    }
    #endregion

}
