﻿/*----------------------------------------------------------------
//  <copyright file="IDemoStore.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Data;
using EaCloud.Template.Pack.Demo.Core.Dtos;
using System.Linq;
using System.Threading.Tasks;
using DemoEntity = EaCloud.Template.Pack.Demo.Core.Entities.Demo;

namespace EaCloud.Template.Pack.Demo.Core
{
    #region "Demo存储功能接口"
    /// <summary>
    /// Demo存储功能接口
    /// </summary>
    public interface IDemoStore
    {
        #region "属性"
        #region "获取 Demo实体查询数据集"
        /// <summary>
        /// 获取 Demo实体查询数据集
        /// </summary>
        IQueryable<DemoEntity> Demos { get; }
        #endregion

        #endregion

        #region "方法"
        #region "新增"
        /// <summary>
        /// 新增
        /// </summary>
        /// <param name="demoEntities">数据实体</param>
        /// <returns></returns>
        OperationResult Insert(params DemoEntity[] demoEntities);
        #endregion
        #region "异步新增"
        /// <summary>
        /// 异步新增
        /// </summary>
        /// <param name="demoEntities">数据实体</param>
        /// <returns></returns>
        Task<OperationResult> InsertAsync(params DemoEntity[] demoEntities);
        #endregion
        #region "更新"
        /// <summary>
        /// 更新
        /// </summary>
        /// <param name="demoEntities">数据实体</param>
        /// <returns></returns>
        OperationResult Update(params DemoEntity[] demoEntities);
        #endregion
        #region "异步更新"
        /// <summary>
        /// 异步更新
        /// </summary>
        /// <param name="demoEntities">数据实体</param>
        /// <returns></returns>
        Task<OperationResult> UpdateAsync(params DemoEntity[] demoEntities);
        #endregion
        #region "删除"
        /// <summary>
        /// 删除
        /// </summary>
        /// <param name="demoEntities">数据实体</param>
        /// <returns></returns>
        OperationResult Delete(params DemoEntity[] demoEntities);
        #endregion
        #region "异步删除"
        /// <summary>
        /// 异步删除
        /// </summary>
        /// <param name="keys">数据实体编号</param>
        /// <returns></returns>
        Task<OperationResult> DeleteAsync(long[] keys);
        #endregion

        #region "异步以DTO为载体新增"
        /// <summary>
        /// 异步以DTO为载体新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        Task<OperationResult> InsertByDtoAsync(params DemoInputDto[] dtos);
        #endregion
        #region "异步以DTO为载体更新"
        /// <summary>
        /// 异步以DTO为载体新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        Task<OperationResult> UpdateByDtoAsync(params DemoInputDto[] dtos);
        #endregion
        #region "异步以DTO为载体更新"
        /// <summary>
        /// 异步以DTO为载体新增
        /// </summary>
        /// <param name="dtos">DTO信息</param>
        /// <returns>业务操作结果</returns>
        Task<OperationResult> UpdateByDtoAsync(params DemoDto[] dtos);
        #endregion

        #endregion

    }
    #endregion

}
