﻿/*----------------------------------------------------------------
//  <copyright file="UserSeedDataInitializer.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-19 09:48</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Entity;
using EaCloud.Pack.Identity.Core;
using EaCloud.Pack.Identity.Core.Dtos;
using EaCloud.Pack.Identity.Core.Entities;
using Microsoft.Extensions.DependencyInjection;
using System;
using System.Linq.Expressions;

namespace EaCloud.Template.Pack.Demo.Core
{
    #region "用户种子数据初始值设定项"
    /// <summary>
    /// 用户种子数据初始值设定项
    /// </summary>
    public class UserSeedDataInitializer : SeedDataInitializerBase<User, long>
    {
        #region "构造函数"
        #region "初始化一个用户种子数据初始值设定项的新实例"
        /// <summary>
        /// 初始化一个用户种子数据初始值设定项（<see cref="UserSeedDataInitializer"/>）的新实例
        /// </summary>
        /// <param name="rootProvider"></param>
        public UserSeedDataInitializer(IServiceProvider rootProvider)
            : base(rootProvider)
        { }
        #endregion

        #endregion

        #region "方法"
        #region "重写以提供要初始化的种子数据"
        /// <summary>
        /// 重写以提供要初始化的种子数据
        /// </summary>
        /// <param name="provider">服务提供者</param>
        /// <returns></returns>
        protected override User[] SeedData(IServiceProvider provider)
        {
            return new[]
            {
                new User(){ UserName = "DemoUser1", NickName = "一号样例用户", Email = "DemoUser1@Demo.com",PhoneNumber = "13910733520",PasswordHash = "p@ssw0rd" },
                new User(){ UserName = "DemoUser2", NickName = "二号样例用户", Email = "DemoUser2@Demo.com",PhoneNumber = "13910733521",PasswordHash = "p@ssw0rd" },
            };
        }
        #endregion
        #region "重写以提供判断某个实体是否存在的表达式"
        /// <summary>
        /// 重写以提供判断某个实体是否存在的表达式
        /// </summary>
        /// <param name="entity">要判断的实体</param>
        /// <returns></returns>
        protected override Expression<Func<User, bool>> ExistingExpression(User entity)
        {
            return m => m.UserName.Equals(entity.UserName);
        }
        #endregion

        #region "将种子数据初始化到数据库"
        /// <summary>
        /// 将种子数据初始化到数据库
        /// </summary>
        /// <param name="entities">实体对象数组</param>
        /// <param name="provider">服务提供者</param>
        protected override void SyncToDatabase(User[] entities, IServiceProvider provider)
        {
            if (entities == null || entities.Length == 0)
            {
                return;
            }

            provider.BeginUnitOfWorkTransaction(provider =>
            {
                var identityContract = provider.GetService<IIdentityContract>();
                foreach (var entity in entities)
                {
                    RegisterDto dto = new()
                    {
                        UserName = entity.UserName,
                        NickName = entity.NickName,
                        Password = entity.PasswordHash,
                        ConfirmPassword = entity.PasswordHash,
                        Email = entity.Email,
                        PhoneNumber = entity.PhoneNumber
                    };
                    var result = identityContract.Register(UserRegisterType.Neither, dto).Result;
                }
            });
        }
        #endregion

        #endregion

    }
    #endregion

}
