﻿/*----------------------------------------------------------------
//  <copyright file="DemoConfiguration.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Entity;
using Microsoft.EntityFrameworkCore;
using Microsoft.EntityFrameworkCore.Metadata.Builders;
using DemoEntity = EaCloud.Template.Pack.Demo.Core.Entities.Demo;

namespace EaCloud.Template.Pack.Demo.EntityConfiguration
{
    #region "Demo实体映射配置"
    /// <summary>
    /// Demo实体映射配置
    /// </summary>
    public partial class DemoConfiguration : EntityTypeConfigurationBase<DemoEntity, long>
    {
        #region "方法"
        #region "重写以实现实体类型各个属性的数据库配置"
        /// <summary>
        /// 重写以实现实体类型各个属性的数据库配置
        /// </summary>
        /// <param name="builder">实体类型创建器</param>
        public override void Configure(EntityTypeBuilder<DemoEntity> builder)
        {
            builder.HasIndex(m => new { m.String, m.DeletedTime }).HasDatabaseName("IDX_Demo_String").IsUnique().HasFilter(null);
            builder.HasIndex(m => m.Guid).HasDatabaseName("IDX_Demo_Guid").IsUnique();
            builder.HasIndex(m => m.OrganizationId).HasDatabaseName("IX_Demo_OrganizationId").IsUnique(false);

            //外键配置示例（具体参考EF Core相关文档）
            //builder.HasOne(ur => ur.MainTable).WithMany().HasForeignKey(m => m.MainTableId).HasConstraintName("FK_Demo_XXX").IsRequired();
            //builder.HasOne(ur => ur.MainTable).WithMany(r => r.SubTableList).HasForeignKey(m => m.MainTableId).HasConstraintName("FK_Demo_XXXX").IsRequired(false);

            EntityConfigurationAppend(builder);
        }
        #endregion
        #region "额外的数据映射"
        /// <summary>
        /// 额外的数据映射
        /// </summary>
        /// <param name="builder"></param>
        partial void EntityConfigurationAppend(EntityTypeBuilder<DemoEntity> builder);
        #endregion

        #endregion

    }
    #endregion
}
