﻿/*----------------------------------------------------------------
//  <copyright file="HangfireJobRunner.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-17 19:06</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Dependency;
using EaCloud.Hangfire;
using Hangfire;
using Microsoft.Extensions.DependencyInjection;
using System;

namespace EaCloud.Template.Svc.Hangfire
{
    #region "Hangfire作业运行器"
    /// <summary>
    /// Hangfire作业运行器
    /// </summary>
    [Dependency(ServiceLifetime.Singleton)]
    public class HangfireJobRunner : IHangfireJobRunner
    {
        /// <summary>
        /// 启动作业运行器
        /// </summary>
        public void Start()
        {
            //BackgroundJob.Enqueue<UserManager<User>>(m => m.FindByIdAsync("2"));
            //string jobId = BackgroundJob.Schedule<UserManager<User>>(m => m.FindByIdAsync("2"), TimeSpan.FromMinutes(2));
            //BackgroundJob.ContinueJobWith<TestHangfireJob>(jobId, m => m.GetUserCount());

            //队列任务
            BackgroundJob.Enqueue(() => Console.WriteLine($@"队列任务"));

            //延时任务
            var jobId = BackgroundJob.Schedule(() => Console.WriteLine($@"延时任务"), TimeSpan.FromMinutes(1));

            //延续性任务执行
            BackgroundJob.ContinueJobWith(jobId, () => Console.WriteLine($@"延续性任务执行"));

            //定时任务
            RecurringJob.AddOrUpdate("1", () => Console.WriteLine($@"定时任务：每年的4月12号15点52分任意秒执行 没加时区 小时+8"), "* 52 15 12 4 *");   //每年的4月12号15点52分任意秒执行 没加时区 小时+8
            RecurringJob.AddOrUpdate("2", () => Console.WriteLine($@"定时任务：每分钟执行一次"), Cron.Minutely);      //每分钟执行一次。
            RecurringJob.AddOrUpdate("3", () => Console.WriteLine($@"定时任务：每天18点36分 当前时区"), Cron.Daily(18, 36), TimeZoneInfo.Local);  //每天18点36分 当前时区

            //本机示例
            RecurringJob.AddOrUpdate<TestHangfireJob>(m => m.Test(), Cron.Minutely, TimeZoneInfo.Local);
            //RecurringJob.AddOrUpdate<TestHangfireJob>(m => m.GetUserCount(), Cron.Minutely, TimeZoneInfo.Local);
            //RecurringJob.AddOrUpdate<TestHangfireJob>(m => m.LockUser2(), Cron.Minutely, TimeZoneInfo.Local);
        }
    }
    #endregion

}
