﻿/*----------------------------------------------------------------
//  <copyright file="MySqlDefaultDbContextMigrationPack.cs" company="EaCloud项目团队">
//      Copyright (c) 2020-2021 SeonSoft. All rights reserved.
//  </copyright>
//  <site>http://www.seonsoft.biz</site>
//  <last-editor>Seon.Hu</last-editor>
//  <last-date>2021-04-19 10:05</last-date>
//----------------------------------------------------------------*/

using EaCloud;
using EaCloud.Core.Packs;
using EaCloud.Entity;
using EaCloud.Entity.MySql;
using System;
using System.ComponentModel;

namespace EaCloud.Template.Svc.Startups
{
    /// <summary>
    /// MySql-DefaultDbContext迁移模块
    /// </summary>
    [DependsOnPacks(typeof(MySqlEntityFrameworkCorePack))]
    [Description("MySql-DefaultDbContext迁移模块")]
    public class MySqlDefaultDbContextMigrationPack : MigrationPackBase<DefaultDbContext>
    {
        #region "属性"
        #region "获取 数据库类型"
        /// <summary>
        /// 获取 数据库类型
        /// </summary>
        protected override DatabaseType DatabaseType => DatabaseType.MySql;
        #endregion
        #region "获取 模块启动顺序"
        /// <summary>
        /// 获取 模块启动顺序，模块启动的顺序先按级别启动，同一级别内部再按此顺序启动，
        /// 级别默认为0，表示无依赖，需要在同级别有依赖顺序的时候，再重写为>0的顺序值
        /// </summary>
        public override int Order => 2;
        #endregion

        #endregion

        #region "重写方法"
        #region "重写实现获取数据上下文实例"
        /// <summary>
        /// 重写实现获取数据上下文实例
        /// </summary>
        /// <param name="scopedProvider">服务提供者</param>
        /// <returns></returns>
        protected override DefaultDbContext CreateDbContext(IServiceProvider scopedProvider)
        {
            return new DesignTimeDefaultDbContextFactory(scopedProvider).CreateDbContext(Array.Empty<string>());
        }
        #endregion

        #endregion

    }
}
